Index: trunk/MagicSoft/Mars/mhistmc/MHMcCollectionArea.cc
===================================================================
--- trunk/MagicSoft/Mars/mhistmc/MHMcCollectionArea.cc	(revision 2077)
+++ trunk/MagicSoft/Mars/mhistmc/MHMcCollectionArea.cc	(revision 2097)
@@ -56,6 +56,6 @@
     //   initialize the histogram for the distribution r vs E
     //
     //   we set the energy range from 10 Gev to 20000 GeV (in log 5 orders
     //   of magnitude) and for each order we take 10 subdivision --> 50 xbins
     //
     //   we set the radius range from 0 m to 500 m with 10 m bin --> 50 ybins
@@ -66,5 +66,5 @@
     MBinning binsx;
     MBinning binsy;
-    binsx.SetEdgesLog(50, 10, 20000);
+    binsx.SetEdgesLog(100, 2., 20000);
     binsy.SetEdges   (50,  0,   500);
 
@@ -56,6 +56,6 @@
     //   initialize the histogram for the distribution r vs E
     //
-    //   we set the energy range from 10 Gev to 20000 GeV (in log 5 orders
-    //   of magnitude) and for each order we take 10 subdivision --> 50 xbins
+    //   we set the energy range from 2 Gev to 20000 GeV (in log 4 orders
+    //   of magnitude) and for each order we take 25 subdivision --> 100 xbins
     //
     //   we set the radius range from 0 m to 500 m with 10 m bin --> 50 ybins
